@@ -36,19 +36,20 @@ def parse_arguments(arguments):
     source = arguments.get("SOURCE")
     destination = arguments.get("DEST")
     keep = -1 if arguments.get("--keep-all") else abs(int(arguments.get("--keep")))
-    keep_days = None if keep < 0 else timedelta(days=keep)
+    keep_td = None if keep < 0 else timedelta(days=keep)
+    keep_all = keep == -1
     dry_run = arguments.get("--dry-run")
-    return source, destination, keep_days, dry_run
+    return source, destination, keep_td, keep_all, dry_run
 
 
-def process_dir(src_dir, dest_dir, keep_days, dry_run):
+def process_dir(src_dir, dest_dir, keep_td, keep_all, dry_run):
     stats = ProcessStats(started_at=NOW)
 
     for root, dirs, files in os.walk(src_dir):
         for filename in files:
             path = os.path.join(root, filename)
 
-            file_stats = process_file(path, dest_dir, keep_days, dry_run)
+            file_stats = process_file(path, dest_dir, keep_td, keep_all, dry_run)
             stats.files_processed += 1
 
             if file_stats.skip_reason:
@@ -66,7 +67,7 @@ def process_dir(src_dir, dest_dir, keep_days, dry_run):
     return stats
 
 
-def process_file(src, dst_dir, keep_days, dry_run):
+def process_file(src, dst_dir, keep_td, keep_all, dry_run):
     stats = fileinfo.analyze_file(src)
     filename = os.path.split(src)[-1]
 
@@ -76,7 +77,7 @@ def process_file(src, dst_dir, keep_days, dry_run):
     stats.skip_reason = fileinfo.find_skip_reason(stats.is_image, stats.target_path)
     if not stats.skip_reason and not dry_run:
         os.makedirs(target_dir, exist_ok=True)
-        if keep_days and keep_days >= NOW - stats.created_at:
+        if keep_all or (keep_td is not None and keep_td >= NOW - stats.created_at):
             shutil.copy2(src, stats.target_path)
         else:
             shutil.move(src, stats.target_path)
@@ -105,13 +106,13 @@ def print_stats(stats):
 
 def main(arguments=None):
     if not arguments:
-        arguments = docopt(__doc__, version="imagemv 0.3.0")
+        arguments = docopt(__doc__, version="imagemv 0.3.1")
 
     logging.basicConfig(
         level=logging.DEBUG if arguments.get("--verbose") else logging.INFO
     )
     logging.debug(f"arguments:{dict(arguments)}")
 
-    source, destination, keep_days, dry_run = parse_arguments(arguments)
-    stats = process_dir(source, destination, keep_days, dry_run)
+    source, destination, keep_td, keep_all, dry_run = parse_arguments(arguments)
+    stats = process_dir(source, destination, keep_td, keep_all, dry_run)
     print_stats(stats)
